SystemOrganization addCategory: #GODAcademicsTests!

TestCase subclass: #ACADAttributeTest
	instanceVariableNames: 'attribute mock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademicsTests'!

!ACADAttributeTest methodsFor: 'initialize-release' stamp: 'ib 10/17/2014 15:54'!
setUp
	attribute := ACADAttribute new.
	mock := TUMock new.
	ACADTagPool clear.! !

!ACADAttributeTest methodsFor: 'testing' stamp: 'ib 10/17/2014 14:44'!
testInitializationFromHTML
	| attr |
	mock when: #from:start:end: do: [:h :s :e | (Array new: 1) at: 1 put: 'AAA'; yourself].
	attribute instVarNamed: 'filter' put: mock.
	attr := attribute from: '<a>AAA</a>' start: '<a>' end: '</a>' at: 1.
	self assert: attr value = 'AAA'.! !

!ACADAttributeTest methodsFor: 'testing' stamp: 'rmc 10/12/2014 16:06'!
testValue
	"tests the set and get operations"

	attribute value: 'testando123'.
	self assert: (attribute value = 'testando123').
	! !

TestCase subclass: #ACADPaperTest
	instanceVariableNames: 'paper mock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademicsTests'!

!ACADPaperTest methodsFor: 'initialize-release' stamp: 'ib 10/17/2014 15:55'!
setUp
	"alloc memory"

	paper := ACADPaper new.
	ACADTagPool clear.
	mock := TUMock new.! !

!ACADPaperTest methodsFor: 'testing' stamp: 'rmc 10/17/2014 15:39'!
testCoauthors
	"tests the coauthors getter and setter"

	paper coauthors: 'Kon F. , Goldman A.'.
	self assert: (paper coauthors = 'Kon F. , Goldman A.').! !

!ACADPaperTest methodsFor: 'testing' stamp: 'rmc 10/17/2014 15:38'!
testImpactFactor
	"tests the impactFactor getter and setter"

	paper impactFactor: 'A1'.
	self assert: (paper impactFactor = 'A1').! !

!ACADPaperTest methodsFor: 'testing' stamp: 'ib 10/17/2014 15:58'!
testInitializeAPaperWithAHTML
	| pool |

	pool := ACADTagPool singleton.
	mock when: #from:start:end: do: [:h :s :e | (Array new: 2) at: 1 put: 'AAA'; at: 2 put: 'BBB'; yourself].
	pool instVarNamed: 'filter' put: mock.
	paper instVarNamed: 'tagPool' put: pool.

	paper withPaper: 'aHTML...'.
	self assert: paper name = 'AAA'.
	self assert: paper coauthors = 'AAA'.
	self assert: paper journal = 'AAA'.
	self assert: paper year = 'BBB'.
	self assert: paper numberOfCitations = 'AAA'.! !

!ACADPaperTest methodsFor: 'testing' stamp: 'rmc 10/12/2014 16:12'!
testJournal
	"tests the journal getter and setter"

	paper journal: 'ACM Journal'.
	self assert: (paper journal = 'ACM Journal').! !

!ACADPaperTest methodsFor: 'testing' stamp: 'rmc 10/17/2014 15:36'!
testName
	"tests the name getter and setter"

	paper name: 'Reflective ORB'.
	self assert: (paper name = 'Reflective ORB').! !

!ACADPaperTest methodsFor: 'testing' stamp: 'rmc 10/17/2014 15:39'!
testNumberOfCitation
	"tests the numberOfCitation getter and setter"

	paper numberOfCitations: '301'.
	self assert: (paper numberOfCitations = '301').! !

!ACADPaperTest methodsFor: 'testing' stamp: 'rmc 10/17/2014 15:37'!
testYear
	"tests the year getter and setter"

	paper year: '2005'.
	self assert: (paper year = '2005').! !

TestCase subclass: #ACADResearcherTest
	instanceVariableNames: 'mock pool researcher'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademicsTests'!

!ACADResearcherTest methodsFor: 'initialization' stamp: 'rmc 10/17/2014 17:42'!
setUp
	mock := TUMock new.
	ACADTagPool clear.
	pool := ACADTagPool singleton.
	researcher := ACADResearcher new.! !

!ACADResearcherTest methodsFor: 'testing' stamp: 'ib 10/17/2014 16:21'!
testInitilizeAResearcherWithPage.
	mock when: #from:start:end: do: [:h :s :e | (Array new: 3) at: 1 put: 'AAA'; at: 2 put: 'BBB'; at: 3 put: 'CCC'; yourself].
	pool instVarNamed: 'filter' put: mock.
	researcher instVarNamed: 'tagPool' put: pool.

	researcher withPage: 'aHTML...'.
	self assert: researcher name = 'AAA'.
	self assert: researcher job = 'AAA'.
	self assert: researcher papers size = 3.! !

!ACADResearcherTest methodsFor: 'testing' stamp: 'ib 10/17/2014 18:02'!
testIteratePapers
	| i |
	mock when: #from:start:end: do: [:h :s :e | (Array new: 3) at: 1 put: 'AAA'; at: 2 put: 'BBB'; at: 3 put: 'CCC'; yourself].
	pool instVarNamed: 'filter' put: mock.
	researcher instVarNamed: 'tagPool' put: pool.

	researcher withPage: 'aHTML...'.

	i := 0.
	researcher forEachPaperDo: [:paper | i := i + 1 ].
	self assert: i = 3! !

!ACADResearcherTest methodsFor: 'testing' stamp: 'rmc 10/17/2014 21:41'!
testPapersByImpactDict
	"tests"
	|p1 p2 p3 table|	

	table := Dictionary new.	
	p1 := ACADPaper new impactFactor:'A2'	.
	p2 := ACADPaper new impactFactor:'A2'	.
	p3 := ACADPaper new impactFactor:'C'.

	researcher papers add: p1; add: p2; add: p3.
	table at: 'A1' put: 0; at: 'A2' put: 2; at: 'B1' put: 0 ;at: 'B2' put: 0 ;at: 'B3' put: 0; 
													at: 'B4' put: 0; at: 'B5' put: 0; at: 'C' put: 1.

	self assert: researcher papersByImpactDict = table.! !

!ACADResearcherTest methodsFor: 'testing' stamp: 'ib 10/17/2014 18:29'!
testTotalNumberOfCitations
	mock when: #from:start:end: do: [:h :s :e | (Array new: 3) at: 1 put: '11'; at: 2 put: 'BBB'; at: 3 put: 'CCC'; yourself].
	pool instVarNamed: 'filter' put: mock.
	researcher instVarNamed: 'tagPool' put: pool.

	researcher withPage: 'aHTML...'.
	(researcher papers at: 1) value.
	self assert: researcher totalNumberOfCitations = 33! !

TestCase subclass: #ACADTagPoolTest
	instanceVariableNames: 'pool mock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademicsTests'!

!ACADTagPoolTest methodsFor: 'testing' stamp: 'ib 10/17/2014 16:12'!
setUp
	mock := TUMock new.
	ACADTagPool clear.
	pool := ACADTagPool singleton.! !

!ACADTagPoolTest methodsFor: 'testing' stamp: 'ib 10/17/2014 15:34'!
testGetAttributes
	| attrs | 
	mock when: #from:start:end: do: [:h :s :e | (Array new: 1) at: 1 put: 'AAA'; yourself].
	pool instVarNamed: 'filter' put: mock.
	attrs := pool getAttributes: 'ACADPaper>year' from: 'anHTHMPage...'.
	self assert: attrs size = 1.
	self assert: (attrs at: 1) value = 'AAA'.! !

!ACADTagPoolTest methodsFor: 'testing' stamp: 'ib 10/17/2014 15:31'!
testGetCoauthors
 	| tag | 
	tag := pool get: 'ACADPaper>coauthors'.
	self assert: tag start = '<div class="gs_gray">'.
	self assert: tag end = '</div>'.! !

!ACADTagPoolTest methodsFor: 'testing' stamp: 'ib 10/17/2014 15:32'!
testGetJob
 	| tag | 
	tag := pool get: 'ACADResearcher>job'.
	self assert: tag start = '<div class="gsc_prf_il">'.
	self assert: tag end = '</div>'.! !

!ACADTagPoolTest methodsFor: 'testing' stamp: 'ib 10/17/2014 15:32'!
testGetNumberOfCitations
 	| tag | 
	tag := pool get: 'ACADPaper>numberOfCitations'.
	self assert: tag start = 'class="gsc_a_ac">'.
	self assert: tag end = '</a>'.! !

!ACADTagPoolTest methodsFor: 'testing' stamp: 'ib 10/17/2014 15:33'!
testGetPapers
 	| tag | 
	tag := pool get: 'ACADResearcher>papers'.
	self assert: tag start = '<tr class="gsc_a_tr>'.
	self assert: tag end = '</tr>'.! !

!ACADTagPoolTest methodsFor: 'testing' stamp: 'ib 10/17/2014 15:33'!
testGetYear
 	| tag | 
	tag := pool get: 'ACADPaper>year'.
	self assert: tag start = '<span class="gsc_a_h">'.
	self assert: tag end = '</span>'.! !

TestCase subclass: #ACADTagTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODAcademicsTests'!

!ACADTagTest methodsFor: 'testing' stamp: 'ib 10/16/2014 18:01'!
testAccessors
	| tag |
	tag := ACADTag new start: 'a'; end: 'b'.
	self assert: tag start = 'a'.
	self assert: tag end = 'b'.! !
